@@ -25,8 +25,8 @@ class LineProfiler(Viewer):
     _model_name = Unicode('LineProfilerModel').tag(sync=True)
     _view_module = Unicode('itkwidgets').tag(sync=True)
     _model_module = Unicode('itkwidgets').tag(sync=True)
-    _view_module_version = Unicode('^0.27.5').tag(sync=True)
-    _model_module_version = Unicode('^0.27.5').tag(sync=True)
+    _view_module_version = Unicode('^0.31.4').tag(sync=True)
+    _model_module_version = Unicode('^0.31.4').tag(sync=True)
     point1 = NDArray(dtype=np.float64, default_value=np.zeros((3,), dtype=np.float64),
                      help="First point in physical space that defines the line profile")\
         .tag(sync=True, **array_serialization)\
@@ -86,18 +86,14 @@ class LineProfiler(Viewer):
             point2 = self.point2
         if order is None:
             order = self.order
-        image_from_array = to_itk_image(image_or_array)
-        if image_from_array:
-            image_ = image_from_array
-        else:
-            image_ = image_or_array
-        image_array = itk.array_view_from_image(image_)
-        dimension = image_.GetImageDimension()
+        image = to_itk_image(image_or_array)
+        image_array = itk.array_view_from_image(image)
+        dimension = image.GetImageDimension()
         distance = np.sqrt(
             sum([(point1[ii] - point2[ii])**2 for ii in range(dimension)]))
-        index1 = tuple(image_.TransformPhysicalPointToIndex(
+        index1 = tuple(image.TransformPhysicalPointToIndex(
             tuple(point1[:dimension])))
-        index2 = tuple(image_.TransformPhysicalPointToIndex(
+        index2 = tuple(image.TransformPhysicalPointToIndex(
             tuple(point2[:dimension])))
         num_points = int(np.round(
             np.sqrt(sum([(index1[ii] - index2[ii])**2 for ii in range(dimension)])) * 2.1))
@@ -157,12 +153,14 @@ def line_profile(image, order=2, plotter=None,  # noqa: C901
         plotter = 'ipympl'
 
     if plotter == 'plotly':
+        import plotly.graph_objs as go
         layout = go.Layout(
             xaxis=dict(title='Distance'),
             yaxis=dict(title='Intensity')
         )
         fig = go.FigureWidget(layout=layout)
     elif plotter == 'bqplot':
+        import bqplot
         x_scale = bqplot.LinearScale()
         y_scale = bqplot.LinearScale()
         x_axis = bqplot.Axis(
